aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/InventoryMenu.h
diff options
context:
space:
mode:
Diffstat (limited to 'Minecraft.World/InventoryMenu.h')
-rw-r--r--Minecraft.World/InventoryMenu.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/Minecraft.World/InventoryMenu.h b/Minecraft.World/InventoryMenu.h
index b37a4be9..cd18f95f 100644
--- a/Minecraft.World/InventoryMenu.h
+++ b/Minecraft.World/InventoryMenu.h
@@ -23,22 +23,22 @@ public:
static const int USE_ROW_SLOT_END;
public:
- shared_ptr<CraftingContainer> craftSlots;
- shared_ptr<Container> resultSlots;
+ std::shared_ptr<CraftingContainer> craftSlots;
+ std::shared_ptr<Container> resultSlots;
bool active;
- InventoryMenu(shared_ptr<Inventory> inventory, bool active, Player *player);
+ InventoryMenu(std::shared_ptr<Inventory> inventory, bool active, Player *player);
private:
- void _init(shared_ptr<Inventory> inventory, bool active);
+ void _init(std::shared_ptr<Inventory> inventory, bool active);
public:
- virtual void slotsChanged(); // 4J used to take a shared_ptr<Container> but wasn't using it, so removed to simplify things
- virtual void removed(shared_ptr<Player> player);
- virtual bool stillValid(shared_ptr<Player> player);
- virtual shared_ptr<ItemInstance> quickMoveStack(shared_ptr<Player> player, int slotIndex);
- virtual bool mayCombine(Slot *slot, shared_ptr<ItemInstance> item);
+ virtual void slotsChanged(); // 4J used to take a std::shared_ptr<Container> but wasn't using it, so removed to simplify things
+ virtual void removed(std::shared_ptr<Player> player);
+ virtual bool stillValid(std::shared_ptr<Player> player);
+ virtual std::shared_ptr<ItemInstance> quickMoveStack(std::shared_ptr<Player> player, int slotIndex);
+ virtual bool mayCombine(Slot *slot, std::shared_ptr<ItemInstance> item);
// 4J ADDED,
- virtual shared_ptr<ItemInstance> clicked(int slotIndex, int buttonNum, int clickType, shared_ptr<Player> player);
+ virtual std::shared_ptr<ItemInstance> clicked(int slotIndex, int buttonNum, int clickType, std::shared_ptr<Player> player);
};